summaryrefslogtreecommitdiff
path: root/sw/qa/extras
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2014-01-09 10:45:04 +0100
committerMiklos Vajna <vmiklos@collabora.co.uk>2014-01-09 10:56:46 +0100
commitcda6438cc2c9be0032a80910f7e903dd7775838c (patch)
tree2c3338e730232301c56cfa6b660b1176f4c14cb3 /sw/qa/extras
parent1f5203302b7be632d6a500643e90a63a81ca5d4a (diff)
DOCX export of annotation marks
Change-Id: I1d4fc68458fd50beccf4e149f74ecbdfc78ea77c
Diffstat (limited to 'sw/qa/extras')
-rw-r--r--sw/qa/extras/ooxmlexport/ooxmlexport.cxx13
1 files changed, 5 insertions, 8 deletions
diff --git a/sw/qa/extras/ooxmlexport/ooxmlexport.cxx b/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
index 0354aab4d13c..a584047a86a0 100644
--- a/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
+++ b/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
@@ -210,18 +210,16 @@ DECLARE_OOXMLEXPORT_TEST(defaultTabStopNotInStyles, "empty.odt")
DECLARE_OOXMLEXPORT_TEST(testFdo38244, "fdo38244.docx")
{
-#if 0
- // FIXME port to AnnotationMarks
/*
* Comments attached to a range was imported without the range, check for the fieldmark start/end positions.
*
* oParas = ThisComponent.Text.createEnumeration
* oPara = oParas.nextElement
* oRuns = oPara.createEnumeration
* oRun = oRuns.nextElement
- * oRun = oRuns.nextElement 'TextFieldStart
+ * oRun = oRuns.nextElement 'Annotation
* oRun = oRuns.nextElement
- * oRun = oRuns.nextElement 'TextFieldEnd
+ * oRun = oRuns.nextElement 'AnnotationEnd
* xray oRun.TextPortionType
*/
uno::Reference<text::XTextDocument> xTextDocument(mxComponent, uno::UNO_QUERY);
@@ -231,10 +229,10 @@ DECLARE_OOXMLEXPORT_TEST(testFdo38244, "fdo38244.docx")
uno::Reference<container::XEnumeration> xRunEnum = xRunEnumAccess->createEnumeration();
xRunEnum->nextElement();
uno::Reference<beans::XPropertySet> xPropertySet(xRunEnum->nextElement(), uno::UNO_QUERY);
- CPPUNIT_ASSERT_EQUAL(OUString("TextFieldStart"), getProperty<OUString>(xPropertySet, "TextPortionType"));
+ CPPUNIT_ASSERT_EQUAL(OUString("Annotation"), getProperty<OUString>(xPropertySet, "TextPortionType"));
xRunEnum->nextElement();
xPropertySet.set(xRunEnum->nextElement(), uno::UNO_QUERY);
- CPPUNIT_ASSERT_EQUAL(OUString("TextFieldEnd"), getProperty<OUString>(xPropertySet, "TextPortionType"));
+ CPPUNIT_ASSERT_EQUAL(OUString("AnnotationEnd"), getProperty<OUString>(xPropertySet, "TextPortionType"));
/*
* Initials were not imported.
@@ -272,7 +270,6 @@ DECLARE_OOXMLEXPORT_TEST(testFdo38244, "fdo38244.docx")
bCaught = true;
}
CPPUNIT_ASSERT_EQUAL(true, bCaught);
-#endif
}
DECLARE_OOXMLEXPORT_TEST(testMathEscape, "math-escape.docx")
@@ -210,18 +210,16 @@ DECLARE_OOXMLEXPORT_TEST(defaultTabStopNotInStyles, "empty.odt")
/*
- * Comments attached to a range was imported without the range, check for the fieldmark start/end positions.
+ * Comments attached to a range was imported without the range, check for the annotation mark start/end positions.
*
* oParas = ThisComponent.Text.createEnumeration